# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import torch
import torch.nn as nn


class LogisticRegression(nn.Module):
    """Radiological signs to Tuberculosis module."""

    def __init__(self, input_size):
        super().__init__()
        self.linear = torch.nn.Linear(input_size, 1)

    def forward(self, x):
        """

        Parameters
        ----------

        x : list
            list of tensors.

        Returns
        -------

        tensor : :py:class:`torch.Tensor`

        """
        output = self.linear(x)

        return output


def build_logistic_regression(input_size):
    """Build logistic regression module.

    Returns
    -------

    module : :py:class:`torch.nn.Module`
    """
    model = LogisticRegression(input_size)
    model.name = "logistic_regression"
    return model
